#####################################################################
#:MyTrigger.pm
#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 2001, 2008 All Rights Reserved
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Copyright 2001 Rational Software Corporation. All Rights Reserved
# This software contains proprietary and confidential information of
# Rational and its suppliers.  Use, disclosure or reproduction is
# prohibited without the prior express written consent of Rational.

=head1 NAME

CQCC::MyTrigger - TriggerCQCC subclass template.

=head1 CLASS DESCRIPTION

<CHANGE> Modify description depending on the purpose of your trigger.

NOTE: Anyone interested in understanding how the overall trigger works
or who is contemplating customizing the behavior of the trigger should
start with a review of the TriggerCQCC class and how its methods
work. Most changes in visible behavior of the trigger will involve
changes in this class. For additional source code documentation,
contact Rational Customer Support.

If local changes are needed, do NOT make them directly to the
TriggerCQCC source code: make a copy of the MyTrigger template class,
rename it, and make your changes there by overriding or extending the
TriggerCQCC methods.  Doing this will facilitate upgrading to later
releases of the CQCC trigger from Rational and provide a fallback to
the released trigger for working with Rational Customer Support.

For example, to create a TriggerCQCC subclass called TriggerLocal,
follow these steps: 

1) Copy MyTrigger.pm to TriggerLocal.pm.

2) Globally replace "MyTrigger" with "TriggerLocal".

3) Copy only the TriggerCQCC methods that you want to change to
   TriggerLocal.pm. All other methods will be inherited from 
   TriggerCQCC without needing to copy them. 

4) Make your code changes in the copy of the method in 
   TriggerLocal.pm. 

5) Modify your configuration file (config.pl) to use your subclass
   for the trigger. 

   &SetConfigParm("TriggerInterface", "CQCC::TriggerLocal");

SUPPORT POLICY: See TriggerCQCC.pm for the Rational Support Policy. 

=head1 METHODS

=cut

######################################################################
#::Package CQCC::MyTrigger
######################################################################

package CQCC::MyTrigger;
use CQCC::TriggerCQCC;
@ISA = ("CQCC::TriggerCQCC" );
use strict;

# Note: These classes are all the base classes that the trigger
# needs directly. At runtime, subclasses may actually be loaded
# and used instead. For example, CQuest is specified here but
# in practice either CQWeb or CQPerlAPI would be used. 

use CQCC::CQuest;
use CQCC::CCase;
use CQCC::IOBase;
use CQCC::Parm;
use CQCC::AssocList;
use CQCC::Timer;
use CQCC::CQSchema;

sub Version { return '2.1' };

######################################################################
#::Class Globals 
######################################################################

######################################################################
#::ClassInit 
# Copy the ClassInit function and the call to it
# only if you need to add new class parameters (DefineParm calls).
######################################################################

######################################################################
#::method new

=over 6

=item C<new CQCC::MyTrigger()>

=back

=cut

######################################################################

sub new { 
   my $proto = shift;
   my $class = ref($proto) || $proto;  # Object or class name

   my $self = new CQCC::TriggerCQCC();   #Make instance of superclass

   # Attributes
   $self->{CLASSNAME} = "CQCC::MyTrigger";

   # $self->{MY_VAR} = undef;

   # This will process any remaining arguments and add/override
   # the existing instance vars. 

   my @args = @_;
   while (@args) {
      my $key = shift @args;
      $self->{$key} = shift @args;
   } 

   # This will turn the $self hash into an object instance.

   bless($self, $class);
   return $self;
}
